@@ -730,7 +730,7 @@ file and then insert its contents.  In this case, format the
 contents as a typographic list.  If ADD-LINKS is `id-only', then
 insert links as `denote-link' does when supplied with an ID-ONLY
 argument."
-  (when (denote-file-is-note-p file)
+  (when (denote-file-has-denoted-filename-p file)
     (with-temp-buffer
       (when add-links
         (insert
@@ -845,26 +845,31 @@ Used by `org-dblock-update' with PARAMS provided by the dynamic block."
 
 (defun denote-org-dblock--extract-regexp (regexp)
   "Extract REGEXP from the buffer and trim it of surrounding spaces."
-  (when-let* ((_ (save-excursion (re-search-forward regexp nil :no-error)))
-              (match-end (match-end 0))
-              (line-end (line-end-position))
-              (text (buffer-substring-no-properties match-end line-end)))
-    (string-trim text)))
+  (save-excursion
+    (when-let* ((_ (re-search-forward regexp nil :no-error))
+                (match-end (match-end 0))
+                (line-end (line-end-position))
+                (text (buffer-substring-no-properties match-end line-end)))
+      (string-trim text))))
 
-(defun denote-org-dblock--get-file-contents-as-heading (file add-links)
+(defun denote-org-dblock--get-file-contents-as-heading (file add-links exclude-tags)
   "Insert the contents of Org FILE, formatting the #+title as a heading.
-With optional ADD-LINKS, make the title link to the original file."
-  (when-let* (((denote-file-is-note-p file))
+With optional ADD-LINKS, make the title link to the original file.  With
+optional EXCLUDE-TAGS, do not add the #+filetags to the end of the
+heading."
+  (when-let* ((_ (denote-file-has-denoted-filename-p file))
               (identifier (denote-retrieve-filename-identifier file))
               (file-type (denote-filetype-heuristics file))
-              ((eq file-type 'org)))
+              (_ (eq file-type 'org)))
     (with-temp-buffer
       (let ((beginning-of-contents (point))
             title
             tags)
         (insert-file-contents file)
         (setq title (denote-org-dblock--extract-regexp (denote--title-key-regexp file-type)))
-        (setq tags (denote-org-dblock--extract-regexp (denote--keywords-key-regexp file-type)))
+        (setq tags (if exclude-tags
+                       ""
+                     (denote-org-dblock--extract-regexp (denote--keywords-key-regexp file-type))))
         (when-let* ((_ (re-search-forward "^$" nil :no-error 1))
                     (match-end (+ (match-end 0) 1))
                     (_ (>= (point-max) match-end)))
@@ -874,13 +879,14 @@ With optional ADD-LINKS, make the title link to the original file."
           (if add-links
               (insert (format "* [[denote:%s][%s]] %s\n\n" identifier title tags))
             (insert (format "* %s %s\n\n" title tags)))
-          (org-align-tags :all))
+          (unless exclude-tags
+            (org-align-tags :all)))
         (while (re-search-forward "^\\(*+?\\) " nil :no-error)
           (replace-match (format "*%s " "\\1")))
         (denote-org-escape-code-in-region beginning-of-contents (point-max)))
       (buffer-string))))
 
-(defun denote-org-dblock-add-files-as-headings (regexp &optional add-links sort-by-component reverse excluded-dirs-regexp exclude-regexp)
+(defun denote-org-dblock-add-files-as-headings (regexp &optional add-links sort-by-component reverse excluded-dirs-regexp exclude-regexp exclude-tags)
   "Insert files matching REGEXP.
 
 If optional ADD-LINKS is non-nil, first insert a link to the file
@@ -899,12 +905,15 @@ Optional EXCLUDED-DIRS-REGEXP is the `let' bound value of
 that user option is used.
 
 Optional EXCLUDE-REGEXP is a more general way to exclude files whose
-name matches the given regular expression."
+name matches the given regular expression.
+
+Optional EXCLUDE-TAGS excludes the #+filetags from the end of the
+heading, where they are otherwise placed."
   (let* ((denote-excluded-directories-regexp (or excluded-dirs-regexp denote-excluded-directories-regexp))
          (files (denote-org-dblock--files regexp sort-by-component reverse exclude-regexp))
          (files-contents (mapcar
                           (lambda (file)
-                            (denote-org-dblock--get-file-contents-as-heading file add-links))
+                            (denote-org-dblock--get-file-contents-as-heading file add-links exclude-tags))
                           files)))
     (insert (string-join files-contents))))
 
@@ -941,7 +950,8 @@ as its own heading."
                            :excluded-dirs-regexp nil
                            :sort-by-component sort-by-component
                            :reverse-sort nil
-                           :add-links nil))
+                           :add-links nil
+                           :exclude-tags nil))
   (org-update-dblock))
 
 ;;;###autoload
@@ -954,9 +964,10 @@ Used by `org-dblock-update' with PARAMS provided by the dynamic block."
          (reverse (plist-get params :reverse-sort))
          (block-name (plist-get params :block-name))
          (add-links (plist-get params :add-links))
+         (exclude-tags (plist-get params :exclude-tags))
          (excluded-dirs (plist-get params :excluded-dirs-regexp)))
     (when block-name (insert "#+name: " block-name "\n"))
-    (when rx (denote-org-dblock-add-files-as-headings rx add-links sort reverse excluded-dirs not-rx)))
+    (when rx (denote-org-dblock-add-files-as-headings rx add-links sort reverse excluded-dirs not-rx exclude-tags)))
   (join-line)) ; remove trailing empty line
 
 ;;;;; Dynamic block to insert hierarchic sequences
@@ -1025,13 +1036,14 @@ With optional FILES operate on them, otherwise use the return value of
 When sequence is an empty string, then use all Denote files with a sequence.
 
 Used by `org-dblock-update' with PARAMS provided by the dynamic block."
-    (let ((block-name (plist-get params :block-name))
-          (depth (plist-get params :depth)))
-      (when-let* ((sequence (plist-get params :sequence))
-                  (parent (denote-sequence-get-path sequence))
-                  (children (denote-sequence-get-relative sequence 'all-children))
-                  (family (push parent children))
-                  (files (denote-org-sequence--get-files-with-max-depth depth family)))
+    (let* ((block-name (plist-get params :block-name))
+           (depth (plist-get params :depth))
+           (sequence (plist-get params :sequence))
+           (all-p (or (string= sequence "") (string= sequence ".+")))
+           (parent (unless all-p (denote-sequence-get-path sequence)))
+           (children (unless all-p (denote-sequence-get-relative sequence 'all-children)))
+           (family (unless all-p (push parent children))))
+      (when-let* ((files (denote-org-sequence--get-files-with-max-depth depth family)))
         (when block-name (insert "#+name: " block-name "\n"))
         (denote-org--insert-sequence files)
         (join-line)))))
